untdl.event.Quit

Package untdl :: Module event :: Class Quit |
[frames] | no frames]

# Class Quit

source code

    object --+
             |
         Event --+
                 |
                Quit

Fired when the window is closed by the user.

Instance Methods
__repr__(self) List an events public attributes when printed. (Inherited from untdl.event.Event) | source code
Inherited from `object`: `__delattr__`, `__format__`, `__getattribute__`, `__hash__`, `__init__`, `__new__`, `__reduce__`, `__reduce_ex__`, `__setattr__`, `__sizeof__`, `__str__`, `__subclasshook__`

Class Variables
| type = ``'``QUIT``'`` String constant representing the type of event.

Properties
Inherited from `object`: `__class__`